package org.eclipse.ui.help;

import java.net.URL;

import org.eclipse.jface.action.IAction;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.ui.contexts.IContext;

/**
 * Compatibility class for Eclipse 3.0 to return an instance of
 * {@link org.eclipse.ui.help.IWorkbenchHelpSystem}.
 * 
 * @see #getHelpSystem()
 */
public class WorkbenchHelpSystem30
{
   // No instances
   private WorkbenchHelpSystem30() {}
   
   /**
    * Compatibility method for Eclipse 3.0 to return an instance of
    * {@link org.eclipse.ui.help.IWorkbenchHelpSystem}
    */
   public static IWorkbenchHelpSystem getHelpSystem() {
      return new IWorkbenchHelpSystem() {

         public boolean hasHelpUI() {
            return true;
         }

         public void displayHelp() {
            WorkbenchHelp.displayHelp();
         }

         public void displaySearch() {
            // no corresponding function in Eclipse 3.0
         }

         public void displayDynamicHelp() {
            // no corresponding function in Eclipse 3.0
         }

         public void search(String expression) {
            // no corresponding function in Eclipse 3.0
         }

         public void displayContext(IContext context, int x, int y) {
            // no corresponding function in Eclipse 3.0
         }

         public void displayHelpResource(String href) {
            WorkbenchHelp.displayHelpResource(href);
         }

         public void displayHelp(String contextId) {
            WorkbenchHelp.displayHelp(contextId);
         }

         public void displayHelp(IContext context) {
            // no corresponding function in Eclipse 3.0
         }

         public boolean isContextHelpDisplayed() {
            return WorkbenchHelp.isContextHelpDisplayed();
         }

         public void setHelp(IAction action, String contextId) {
            WorkbenchHelp.setHelp(action, contextId);
         }

         public void setHelp(Control control, String contextId) {
            WorkbenchHelp.setHelp(control, contextId);
         }

         public void setHelp(Menu menu, String contextId) {
            WorkbenchHelp.setHelp(menu, contextId);
         }

         public void setHelp(MenuItem item, String contextId) {
            WorkbenchHelp.setHelp(item, contextId);
         }

         public URL resolve(String href, boolean documentOnly) {
            // no corresponding function in Eclipse 3.0
            return null;
         }
         
      };
   }
}
