package org.eclipse.ui.operations;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.IWorkbenchPartSite;
import org.eclipse.ui.PlatformUI;


/**
 * <p>
 * UndoActionHandler provides common behavior for performing an undo, as
 * well as labelling and enabling the undo menu item.  This class may be
 * instantiated by clients.
 * </p>
 * 
 * @backported from Eclipse 3.1
 */
public final class UndoActionHandler extends OperationHistoryActionHandler {

   /**
    * Construct an action handler that handles the labelling and enabling of
    * the undo action for the specified undo context.
    * 
    * @param site 
    *            the workbench part site that created the action.
    * @param context 
    *            the undo context to be used for the undo
    */
   public UndoActionHandler(IWorkbenchPartSite site, IUndoContext context) {
      super(site, context);
        setImageDescriptor(PlatformUI.getWorkbench().getSharedImages()
                .getImageDescriptor(ISharedImages.IMG_TOOL_UNDO));
   }

   void flush() {
      getHistory().dispose(undoContext, true, false, false);
   }

   String getCommandString() {
      return "Undo";
   }

   IUndoableOperation getOperation() {
      return getHistory().getUndoOperation(undoContext);

   }

   IStatus runCommand(IProgressMonitor pm) throws ExecutionException  {
      return getHistory().undo(undoContext, pm, this);
   }

   boolean shouldBeEnabled() {
      // if a context was not supplied, do not enable.
      if (undoContext == null)
         return false;
      return getHistory().canUndo(undoContext);
   }
}
