package com.qualityeclipse.favorites.actions;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.jface.action.Action;
import org.eclipse.swt.SWTError;
import org.eclipse.swt.dnd.TextTransfer;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.ui.part.ResourceTransfer;

import com.qualityeclipse.favorites.model.IFavoriteItem;
import com.qualityeclipse.favorites.views.FavoritesView;

public class CopyFavoritesAction extends Action
{
   private FavoritesView view;

   public CopyFavoritesAction(FavoritesView view, String text) {
      super(text);
      this.view = view;
   }

   public void run() {
      IFavoriteItem[] items = view.getSelectedFavorites();
      if (items.length == 0)
         return;
      try {
         view.getClipboard().setContents(
            new Object[] {
               asResources(items),
               asText(items), },
            new Transfer[] {
               ResourceTransfer.getInstance(),
               TextTransfer.getInstance(), });
      }
      catch (SWTError error) {
         // Copy to clipboard failed. 
         // This happens when another application
         // is accessing the clipboard while we copy. 
         // Ignore the error.
      }
   }

   public static IResource[] asResources(IFavoriteItem[] items) {
      List resources = new ArrayList();
      for (int i = 0; i < items.length; i++) {
         IResource res =
            (IResource) items[i].getAdapter(IResource.class);
         if (res != null)
            resources.add(res);
      }
      return (IResource[]) resources.toArray(
         new IResource[resources.size()]);
   }

   public static String asText(IFavoriteItem[] items) {
      StringBuffer buf = new StringBuffer();
      for (int i = 0; i < items.length; i++) {
         if (i > 0)
            buf.append(System.getProperty("line.separator"));
         buf.append(items[i].getName());
      }
      return buf.toString();
   }
}