package com.qualityeclipse.favorites.actions;

import java.util.Iterator;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.actions.ActionDelegate;
import org.eclipse.ui.ide.IDE;

import com.qualityeclipse.favorites.FavoritesLog;

/**
 * Action delegate to open an editor on the currently selected
 * favorites items, if applicable.
 */
public class OpenEditorActionDelegate extends ActionDelegate
{
   /*
    * This action delegate can be turned into an "Open" menu item in
    * the Favorites view context menu.
    */

   /**
    * Open an editor on the first element in the specified selection
    * if that element is file.
    * 
    * @param page the workbench page to contain the editor
    * @param selection the selection
    */
   public static void openEditor(IWorkbenchPage page,
         ISelection selection)
   {

      // Get the first element

      if (!(selection instanceof IStructuredSelection))
         return;
      Iterator iter = ((IStructuredSelection) selection).iterator();
      if (!iter.hasNext())
         return;
      Object elem = iter.next();

      // Adapt the first element to a file

      if (!(elem instanceof IAdaptable))
         return;
      IFile file = (IFile) ((IAdaptable) elem).getAdapter(IFile.class);
      if (file == null)
         return;

      // Open an editor on that file

      try {
         IDE.openEditor(page, file);
      }
      catch (PartInitException e) {
         FavoritesLog.logError(
            "Open editor failed: " + file.toString(), e);
      }
   }
}
