package com.qualityeclipse.favorites.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.qualityeclipse.favorites.FavoritesLog;

/**
 * Simple action delegate to test directly accessing the progress
 * service using a simulated long running operation. Usually this is
 * not necessary because using the Jobs API automaticaly causes
 * progress of background tasks to be displayed in the workbench
 */
public class TestProgressServiceActionDelegate
      implements IWorkbenchWindowActionDelegate
{
   private IWorkbenchWindow window;

   public void init(IWorkbenchWindow window) {
      this.window = window;
   }

   public void selectionChanged(IAction action, ISelection selection) {
   }

   public void run(IAction action) {
      try {
         testWindowRun();
         testProgressService1();
         testProgressService2();
      }
      catch (InvocationTargetException e) {
         FavoritesLog.logError(e);
      }
      catch (InterruptedException e) {
         // Canceled by user... ignore
      }
   }

   private void testWindowRun() throws InvocationTargetException, InterruptedException {
      window.run(true, true, new IRunnableWithProgress() {
         public void run(IProgressMonitor monitor)
            throws InvocationTargetException, InterruptedException 
         {
            monitor.beginTask("simulate status bar progress:", 60);
            for (int i = 60; i > 0; --i) {
               monitor.subTask("seconds left = " + i);
               if (monitor.isCanceled())
                  break;
               Thread.sleep(1000);
               monitor.worked(1);
            }
            monitor.done();
         }
      });
   }

   private void testProgressService1() 
      throws InvocationTargetException, InterruptedException
   {
      window.getWorkbench().getProgressService().run(true, true,
         new IRunnableWithProgress() {
            public void run(IProgressMonitor monitor)
               throws InvocationTargetException, InterruptedException
            {
               monitor.beginTask("Simulated long running task #1", 60);
               for (int i = 60; i > 0; --i) {
                  monitor.subTask("seconds left = " + i);
                  if (monitor.isCanceled())
                     break;
                  Thread.sleep(1000);
                  monitor.worked(1);
               }
               monitor.done();
            }
         });
   }

   private void testProgressService2() 
      throws InvocationTargetException, InterruptedException
   {
      window.getWorkbench().getProgressService().busyCursorWhile(
         new IRunnableWithProgress() {
            public void run(IProgressMonitor monitor)
               throws InvocationTargetException, InterruptedException
            {
               monitor.beginTask("Simulated long running task #2", 60);
               for (int i = 60; i > 0; --i) {
                  monitor.subTask("seconds left = " + i);
                  if (monitor.isCanceled())
                     break;
                  Thread.sleep(1000);
                  monitor.worked(1);
               }
               monitor.done();
            }
         });
   }

   public void dispose() {
   }
}
