package com.qualityeclipse.favorites.builder;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectNature;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;

import com.qualityeclipse.favorites.FavoritesLog;

/**
 * Used to associate the PropertiesFileAuditor builder with a project.
 * This nature adds our builder to the projects build spec and
 * triggers a build in the background when the project is configured.
 * When the nature is removed from the project, the build spec is
 * modified and all audit markers are removed.
 */
public class PropertiesAuditorNature
      implements IProjectNature
{
   private IProject project;

   /**
    * Answer the associated project
    */
   public IProject getProject() {
      return project;
   }

   /**
    * Set the associated project
    */
   public void setProject(IProject project) {
      this.project = project;
   }
   
   /**
    * Configures this nature for its project. This is called by the
    * workspace when natures are added to the project using
    * <code>IProject.setDescription</code>. This nature adds our
    * builder to the projects build spec and triggers a build in the
    * background when the project is configured.
    */
   public void configure() throws CoreException {
      PropertiesFileAuditor.addBuilderToProject(project);
      new Job("Properties File Audit") {
         protected IStatus run(IProgressMonitor monitor) {
            try {
               project.build(
                  PropertiesFileAuditor.FULL_BUILD,
                  PropertiesFileAuditor.BUILDER_ID,
                  null,
                  monitor);
            }
            catch (CoreException e) {
               FavoritesLog.logError(e);
            }
            return Status.OK_STATUS;
         }
      }.schedule();
   }

   /**
    * De-configures this nature for its project. This is called by the
    * workspace when natures are removed from the project using
    * <code>IProject.setDescription</code>. When the nature is
    * removed from the project, the build spec is modified and all
    * audit markers are removed.
    */
   public void deconfigure() throws CoreException {
      PropertiesFileAuditor.removeBuilderFromProject(project);
      PropertiesFileAuditor.deleteAuditMarkers(project);
   }
}
