package com.qualityeclipse.favorites.editors;

import org.eclipse.jface.viewers.ICellModifier;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.widgets.TreeItem;

/**
 * Cell modifiers adapt the underlying model to an interface
 * understood by cell editors so that the cell editors can present the
 * correct value to the user and update the model with new values when
 * a user has made modifications. In this case, the
 * <code>PropertiesEditorCellModifier</code> class adapts the
 * PropertyElement model objects to the PropertyEditor cell editors.
 */
public class PropertiesEditorCellModifier
   implements ICellModifier
{
   private PropertiesEditor editor;

   public PropertiesEditorCellModifier(
      PropertiesEditor editor,
      TreeViewer viewer
   ) {
      this.editor = editor;
   }
   
   public boolean canModify(Object element, String property) {
      if (property == PropertiesEditor.KEY_COLUMN_ID) {
         if (element instanceof PropertyCategory)
            return editor.shouldEdit();
         if (element instanceof PropertyEntry)
            return editor.shouldEdit();
      }
      if (property == PropertiesEditor.VALUE_COLUMN_ID){
         if (element instanceof PropertyEntry)
            return editor.shouldEdit();
      }
      return false;
   }

   public Object getValue(Object element, String property) {
      if (property == PropertiesEditor.KEY_COLUMN_ID) {
         if (element instanceof PropertyCategory)
            return ((PropertyCategory) element).getName();
         if (element instanceof PropertyEntry)
            return ((PropertyEntry) element).getKey();
      }
      if (property == PropertiesEditor.VALUE_COLUMN_ID){
         if (element instanceof PropertyEntry)
            return ((PropertyEntry) element).getValue();
      }
      return null;
   }

   public void modify(Object item, String property, Object value) {
      // Null indicates that the validator rejected the value.
      if (value == null)
         return;

      Object element = item;
      if (element instanceof TreeItem)
         element = ((TreeItem) element).getData();

      String text = ((String) value).trim();
      if (property == PropertiesEditor.KEY_COLUMN_ID) {
         if (element instanceof PropertyCategory)
            ((PropertyCategory) element).setName(text);
         if (element instanceof PropertyEntry)
            ((PropertyEntry) element).setKey(text);
      }
      if (property == PropertiesEditor.VALUE_COLUMN_ID){
         if (element instanceof PropertyEntry)
            ((PropertyEntry) element).setValue(text);
      }
   }
}
