package com.qualityeclipse.favorites.editors;

import java.util.Iterator;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.AbstractTreeViewer;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.swt.widgets.Shell;

public class RemovePropertiesAction extends Action
{
   private final PropertiesEditor editor;
   private final AbstractTreeViewer viewer;

   private ISelectionChangedListener listener =
      new ISelectionChangedListener() {
      public void selectionChanged(SelectionChangedEvent e) {
         setEnabled(!e.getSelection().isEmpty());
      }
   };

   public RemovePropertiesAction(
      PropertiesEditor editor,
      AbstractTreeViewer viewer,
      String text,
      ImageDescriptor imageDescriptor
   ) {
      super(text, imageDescriptor);
      this.editor = editor;
      this.viewer = viewer;
      setEnabled(false);
      viewer.addSelectionChangedListener(listener);
   }
   
   public void run() {
      
      // Build an array of properties to be removed
      IStructuredSelection sel = 
         (IStructuredSelection) viewer.getSelection();
      Iterator iter = sel.iterator();
      int size = sel.size();
      PropertyElement[] elements = new PropertyElement[size];
      for (int i = 0; i < size; i++)
         elements[i] = (PropertyElement) ((Object) iter.next());
      
      // Build the operation to be performed
      RemovePropertiesOperation op = 
         new RemovePropertiesOperation(viewer, elements);
      op.addContext(editor.getUndoContext());
      
      // The progress monitor so the operation can inform the user
      IProgressMonitor monitor = editor.getEditorSite().getActionBars()
            .getStatusLineManager().getProgressMonitor();

      // An adapter for providing UI context to the operation
      IAdaptable info = new IAdaptable() {
         public Object getAdapter(Class adapter) {
            if (Shell.class.equals(adapter))
               return editor.getSite().getShell();
            return null;
         }
      };
      
      // Execute the operation
      try {
         editor.getOperationHistory().execute(op, monitor, info);
      }
      catch (ExecutionException e) {
         MessageDialog.openError(
            editor.getSite().getShell(), 
            "Remove Properties Error",
            "Exception while removing properties: " + e.getMessage());
      }
   }
}