package com.qualityeclipse.favorites.util;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

/**
 * A cache of images accessed by image descriptor. The
 * {@link #dispose()} method must be called to dispose of any cached
 * images before this instance is discarded so that OS resources will
 * be properly cleaned up.
 */
public class ImageCache
{
   /**
    * An internal mapping of descriptor to image
    */
   private final Map imageMap = new HashMap();

   /**
    * Answer the image for the specified descriptor
    * 
    * @param imageDescriptor the descriptor
    * @return the image or <code>null</code> if could not be loaded
    */
   public Image getImage(ImageDescriptor imageDescriptor) {
      if (imageDescriptor == null)
         return null;
      Image image = (Image) imageMap.get(imageDescriptor);
      if (image == null) {
         image = imageDescriptor.createImage();
         imageMap.put(imageDescriptor, image);
      }
      return image;
   }

   /**
    * Dispose of all cached images
    */
   public void dispose() {
      Iterator iter = imageMap.values().iterator();
      while (iter.hasNext())
          ((Image) iter.next()).dispose();
      imageMap.clear();
   }
}
